simple_error_reporter library
Classes
- ErrorReporter
- (en) A general purpose error reporting class.
- ErrorReporterConfig
- (en) Singleton configuration for ErrorReporter and ErrorReporterForNative. Use this to control retry behavior independently of the global RetryConfig in simple_https_service.
- ErrorReporterForNative
- (en) An error reporting class for native devices. This supports the use of self-signed certificates.
- ErrorReportObj
- (en) This is an object for storing basic error content used by ErrorReporter and ErrorReporterForNative.